Package 'JournalAnalysis'

Title: Explore and Identify Journals to Publish in.
Description: A package for exploring and identifying the best journals in which to publish a paper.
Authors: Robert Gilmore [aut, cre], Shaurita Hutchins [aut]
Maintainer: Robert Gilmore <[email protected]>
License: MIT + file LICENSE
Version: 0.2.0
Built: 2026-06-11 04:14:19 UTC
Source: https://github.com/vallenderlab/JournalAnalysis

Help Index


Example Europe PMC queries for package vignettes.

Description

Example Europe PMC queries for package vignettes.

Usage

query1

query2

query3

Format

A character string containing a Europe PMC advanced search query.

An object of class character of length 1.

An object of class character of length 1.

An object of class character of length 1.


Get Article Data

Description

This function retrieves article data from europe pmc.

Usage

get_article_data(
  queries,
  limit = 7500,
  min_year = NULL,
  max_year = NULL,
  min_citations = 5,
  n_cores = default_worker_count()
)

Arguments

queries

Input a Europe PMC query

limit

Minimum number of articles to retrieve

min_year

Minimum publication year

max_year

Maximum publication year

min_citations

Minimum number of citations per article

n_cores

Number of cores to use across multiple queries.

Value

A tibble of the article data


Get Journal Data

Description

This function retrieves journal data from an existing data file.

Usage

get_journal_data(data = "incities")

Arguments

data

A bundled journal source. Use 'incities' (InCites / JCR) or 'scimago'. The aliases 'incites', 'jcr', and 'scimagojr' are also accepted.

Value

A tibble of the journal data.


Get Publication Data

Description

This function uses a journal source to combine data based on queries.

Usage

get_publication_data(
  journal_source,
  queries,
  limit = 7500,
  min_year = NULL,
  max_year = NULL,
  min_citations = 5,
  n_cores = default_worker_count()
)

Arguments

journal_source

Journal metrics source: 'incities' (InCites / JCR) or 'scimago'. Aliases 'incites', 'jcr', and 'scimagojr' are also accepted.

queries

Use one or multiple queries

limit

A minimum number of articles

min_year

Minimum year to search

max_year

Maximum year to search

min_citations

Minimum number of citations in a journal

n_cores

Number of cores to use across multiple queries.

Value

A list of data objects including journals, articles, and combined data.


Get Unique ISSNs

Description

This function filters ISSNs.

Usage

get_unique_issns(issns)

Arguments

issns

The issns from the articles

Value

A tibble of filtered issns


Get Word Cloud

Description

This function imports a list of pubmed ids and creates a word cloud.

Usage

get_word_cloud(pubmed_ids, plot_name)

Arguments

pubmed_ids

A list of pubmed ids

plot_name

Path to the output word cloud


Install JournalAnalysis Packages

Description

This function helps user to install packages used in this package

Usage

install_journalanalysis_packages()

ISSN to Article Data

Description

This function filters article data by ISSN.

Usage

issn_to_article_data(data, issns)

Arguments

data

The data tibble of the articles

issns

The issns from the articles

Value

A tibble of the articles filtered by ISSNs


ISSN to Journal Data

Description

This function retrieves journal data from an existing data file.

Usage

issn_to_journal_data(data, issns)

Arguments

data

The data source of the journal

issns

The issns from the journal source

Value

A tibble of the data filtered by ISSN


InCites Journal Citation Reports via Web of Science (2023)

Description

Journal-level metrics from a 2023 InCites / Journal Citation Reports export. Used by [get_journal_data()] when 'data = "incities"'. The aliases 'incites' and 'jcr' refer to the same bundled dataset.

Usage

jcr2023_wos

Format

## 'jcr2023_wos' A data frame with 21,848 rows and 10 columns:

journal_name

Journal title from the source export.

issn

Print ISSN.

e_issn

Electronic ISSN.

category

One or more JCR subject categories.

edition

Indexed Web of Science edition tags.

total_citations

Total citations in the 2023 source export.

impact_factor_2023

2023 Journal Impact Factor.

jif_quartile

Journal Impact Factor quartile.

jci_2023

2023 Journal Citation Indicator.

percent_oa_gold

Percent gold open access.

<https://raw.githubusercontent.com/bjorn-heilagi/journal-citation-reports-wos/refs/heads/main/datasets/jcr_2023_wos.csv> accessed 2026-06-10.


Save as CSV

Description

This function saves a tibble or dataframe as a csv file.

Usage

save_as_csv(data, filename)

Arguments

data

The dataframe or tibble

filename

Name or path of output file without .csv extension


SCImago Journal & Country Rank (2025)

Description

Journal-level metrics from SCImago Journal & Country Rank for 2025. Used by [get_journal_data()] when 'data = "scimago"' or 'data = "scimagojr"'.

Usage

scimagojr2025

Format

## 'scimagojr2025' A data frame with 32,193 rows and 25 columns:

Rank

SCImago rank from the source export.

Sourceid

SCImago source identifier.

Title

Journal title, with underscores replaced by spaces.

Type

Publication type, such as journal or book series.

Issn

ISSN string from the source export.

Publisher

Publisher name.

Open.Access

Open access flag from the source export.

Open.Access.Diamond

Diamond open access flag.

SJR

SCImago Journal Rank indicator.

SJR.Best.Quartile

Best quartile (Q1-Q4).

H.index

H-index.

Total.Docs...2025.

Documents published in 2025.

Total.Docs...3years.

Documents in the prior three years.

Total.Refs.

Total references.

Total.Citations..3years.

Citations in the prior three years.

Citable.Docs...3years.

Citable documents in the prior three years.

Citations...Doc...2years.

Citations per document, two-year window.

Ref....Doc.

References per document.

X.Female

Percent female authorship from the source export.

Overton

Overton indicator from the source export.

Country

Country of publication.

Region

World region.

Coverage

Source coverage years.

Categories

Subject categories assigned by SCImago.

Areas

Broad subject areas assigned by SCImago.

Local source file 'data/scimagojr_2025.csv', accessed 2026-06-10 from <https://www.scimagojr.com/journalrank.php>.