| Title: | Explore and Identify Journals to Publish in. |
|---|---|
| Description: | A package for exploring and identifying the best journals in which to publish a paper. |
| Authors: | Robert Gilmore [aut, cre], Shaurita Hutchins [aut] |
| Maintainer: | Robert Gilmore <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-06-11 04:14:19 UTC |
| Source: | https://github.com/vallenderlab/JournalAnalysis |
Example Europe PMC queries for package vignettes.
query1 query2 query3query1 query2 query3
A character string containing a Europe PMC advanced search query.
An object of class character of length 1.
An object of class character of length 1.
An object of class character of length 1.
This function retrieves article data from europe pmc.
get_article_data( queries, limit = 7500, min_year = NULL, max_year = NULL, min_citations = 5, n_cores = default_worker_count() )get_article_data( queries, limit = 7500, min_year = NULL, max_year = NULL, min_citations = 5, n_cores = default_worker_count() )
queries |
Input a Europe PMC query |
limit |
Minimum number of articles to retrieve |
min_year |
Minimum publication year |
max_year |
Maximum publication year |
min_citations |
Minimum number of citations per article |
n_cores |
Number of cores to use across multiple queries. |
A tibble of the article data
This function retrieves journal data from an existing data file.
get_journal_data(data = "incities")get_journal_data(data = "incities")
data |
A bundled journal source. Use 'incities' (InCites / JCR) or 'scimago'. The aliases 'incites', 'jcr', and 'scimagojr' are also accepted. |
A tibble of the journal data.
This function uses a journal source to combine data based on queries.
get_publication_data( journal_source, queries, limit = 7500, min_year = NULL, max_year = NULL, min_citations = 5, n_cores = default_worker_count() )get_publication_data( journal_source, queries, limit = 7500, min_year = NULL, max_year = NULL, min_citations = 5, n_cores = default_worker_count() )
journal_source |
Journal metrics source: 'incities' (InCites / JCR) or 'scimago'. Aliases 'incites', 'jcr', and 'scimagojr' are also accepted. |
queries |
Use one or multiple queries |
limit |
A minimum number of articles |
min_year |
Minimum year to search |
max_year |
Maximum year to search |
min_citations |
Minimum number of citations in a journal |
n_cores |
Number of cores to use across multiple queries. |
A list of data objects including journals, articles, and combined data.
This function filters ISSNs.
get_unique_issns(issns)get_unique_issns(issns)
issns |
The issns from the articles |
A tibble of filtered issns
This function imports a list of pubmed ids and creates a word cloud.
get_word_cloud(pubmed_ids, plot_name)get_word_cloud(pubmed_ids, plot_name)
pubmed_ids |
A list of pubmed ids |
plot_name |
Path to the output word cloud |
This function helps user to install packages used in this package
install_journalanalysis_packages()install_journalanalysis_packages()
This function filters article data by ISSN.
issn_to_article_data(data, issns)issn_to_article_data(data, issns)
data |
The data tibble of the articles |
issns |
The issns from the articles |
A tibble of the articles filtered by ISSNs
This function retrieves journal data from an existing data file.
issn_to_journal_data(data, issns)issn_to_journal_data(data, issns)
data |
The data source of the journal |
issns |
The issns from the journal source |
A tibble of the data filtered by ISSN
Journal-level metrics from a 2023 InCites / Journal Citation Reports export. Used by [get_journal_data()] when 'data = "incities"'. The aliases 'incites' and 'jcr' refer to the same bundled dataset.
jcr2023_wosjcr2023_wos
## 'jcr2023_wos' A data frame with 21,848 rows and 10 columns:
Journal title from the source export.
Print ISSN.
Electronic ISSN.
One or more JCR subject categories.
Indexed Web of Science edition tags.
Total citations in the 2023 source export.
2023 Journal Impact Factor.
Journal Impact Factor quartile.
2023 Journal Citation Indicator.
Percent gold open access.
<https://raw.githubusercontent.com/bjorn-heilagi/journal-citation-reports-wos/refs/heads/main/datasets/jcr_2023_wos.csv> accessed 2026-06-10.
This function saves a tibble or dataframe as a csv file.
save_as_csv(data, filename)save_as_csv(data, filename)
data |
The dataframe or tibble |
filename |
Name or path of output file without .csv extension |
Journal-level metrics from SCImago Journal & Country Rank for 2025. Used by [get_journal_data()] when 'data = "scimago"' or 'data = "scimagojr"'.
scimagojr2025scimagojr2025
## 'scimagojr2025' A data frame with 32,193 rows and 25 columns:
SCImago rank from the source export.
SCImago source identifier.
Journal title, with underscores replaced by spaces.
Publication type, such as journal or book series.
ISSN string from the source export.
Publisher name.
Open access flag from the source export.
Diamond open access flag.
SCImago Journal Rank indicator.
Best quartile (Q1-Q4).
H-index.
Documents published in 2025.
Documents in the prior three years.
Total references.
Citations in the prior three years.
Citable documents in the prior three years.
Citations per document, two-year window.
References per document.
Percent female authorship from the source export.
Overton indicator from the source export.
Country of publication.
World region.
Source coverage years.
Subject categories assigned by SCImago.
Broad subject areas assigned by SCImago.
Local source file 'data/scimagojr_2025.csv', accessed 2026-06-10 from <https://www.scimagojr.com/journalrank.php>.